==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfBookmark.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfBookmark(SpireObject):
    """
    Each instance of this class represents an bookmark node in the bookmark tree.
    """

    @property
    def Destination(self) -> 'PdfDestination':
        """
        Gets or sets the outline destination.
        """
        GetDllLibPdf().PdfBookmark_get_Destination.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_get_Destination.restype = c_void_p
        intPtr = GetDllLibPdf().PdfBookmark_get_Destination(self.Ptr)
        ret = None if intPtr == None else PdfDestination(intPtr)
        return ret

    @Destination.setter
    def Destination(self, value: 'PdfDestination'):
        """
        Sets the outline destination.
        """
        GetDllLibPdf().PdfBookmark_set_Destination.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfBookmark_set_Destination(self.Ptr, value.Ptr)

    @property
    def Title(self) -> str:
        """
        Gets or sets the outline title.
        """
        GetDllLibPdf().PdfBookmark_get_Title.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_get_Title.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfBookmark_get_Title(self.Ptr))
        return ret

    @Title.setter
    def Title(self, value: str):
        """
        Sets the outline title.
        """
        GetDllLibPdf().PdfBookmark_set_Title.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfBookmark_set_Title(self.Ptr, value)

    @property
    def Color(self) -> 'PdfRGBColor':
        """
        Gets or sets the color.
        """
        GetDllLibPdf().PdfBookmark_get_Color.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_get_Color.restype = c_void_p
        intPtr = GetDllLibPdf().PdfBookmark_get_Color(self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @Color.setter
    def Color(self, value: 'PdfRGBColor'):
        """
        Sets the color.
        """
        GetDllLibPdf().PdfBookmark_set_Color.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfBookmark_set_Color(self.Ptr, value.Ptr)

    @property
    def DisplayStyle(self) -> 'PdfTextStyle':
        """
        Gets or sets the text style.
        """
        GetDllLibPdf().PdfBookmark_get_DisplayStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_get_DisplayStyle.restype = c_int
        ret = GetDllLibPdf().PdfBookmark_get_DisplayStyle(self.Ptr)
        objwrapped = PdfTextStyle(ret)
        return objwrapped

    @DisplayStyle.setter
    def DisplayStyle(self, value: 'PdfTextStyle'):
        """
        Sets the text style.
        """
        GetDllLibPdf().PdfBookmark_set_DisplayStyle.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfBookmark_set_DisplayStyle(self.Ptr, value.value)

    @property
    def ExpandBookmark(self) -> bool:
        """
        Gets or sets whether to expand or collapse the node.
        """
        GetDllLibPdf().PdfBookmark_get_ExpandBookmark.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_get_ExpandBookmark.restype = c_bool
        ret = GetDllLibPdf().PdfBookmark_get_ExpandBookmark(self.Ptr)
        return ret

    @ExpandBookmark.setter
    def ExpandBookmark(self, value: bool):
        """
        Sets whether to expand or collapse the node.
        """
        GetDllLibPdf().PdfBookmark_set_ExpandBookmark.argtypes = [c_void_p, c_bool]
        GetDllLibPdf().PdfBookmark_set_ExpandBookmark(self.Ptr, value)

    @property
    def Action(self) -> 'PdfAction':
        """
        Gets or sets the Action for the Outline.
        """
        GetDllLibPdf().PdfBookmark_get_Action.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_get_Action.restype = c_void_p
        intPtr = GetDllLibPdf().PdfBookmark_get_Action(self.Ptr)
        ret = None if intPtr == None else PdfAction(intPtr)
        return ret

    @Action.setter
    def Action(self, value: 'PdfAction'):
        """
        Sets the Action for the Outline.
        """
        GetDllLibPdf().PdfBookmark_set_Action.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfBookmark_set_Action(self.Ptr, value.Ptr)

    def ConvertToBookmarkCollection(self) -> 'PdfBookmarkCollection':
        """
        Converts the bookmark to a bookmark collection.
        """
        from spire.pdf.PdfBookmarkCollection import PdfBookmarkCollection
        GetDllLibPdf().PdfBookmark_ConvertToBookmarkCollection.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_ConvertToBookmarkCollection.restype = c_void_p
        intPtr = GetDllLibPdf().PdfBookmark_ConvertToBookmarkCollection(self.Ptr)
        ret = None if intPtr == None else PdfBookmarkCollection(intPtr)
        return ret

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfBookmark.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfBookmark(SpireObject):
    """
    Each instance of this class represents an bookmark node in the bookmark tree.
    """

    @property
    def Destination(self) -> 'PdfDestination':
        """
        Gets or sets the outline destination.
        """
        GetDllLibPdf().PdfBookmark_get_Destination.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_get_Destination.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfBookmark_get_Destination,self.Ptr)
        ret = None if intPtr == None else PdfDestination(intPtr)
        return ret

    @Destination.setter
    def Destination(self, value: 'PdfDestination'):
        """
        Sets the outline destination.
        """
        GetDllLibPdf().PdfBookmark_set_Destination.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfBookmark_set_Destination,self.Ptr, value.Ptr)

    @property
    def Title(self) -> str:
        """
        Gets or sets the outline title.
        """
        GetDllLibPdf().PdfBookmark_get_Title.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_get_Title.restype = c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibPdf().PdfBookmark_get_Title,self.Ptr))
        return ret

    @Title.setter
    def Title(self, value: str):
        """
        Sets the outline title.
        """
        GetDllLibPdf().PdfBookmark_set_Title.argtypes = [c_void_p, c_wchar_p]
        CallCFunction(GetDllLibPdf().PdfBookmark_set_Title,self.Ptr, value)

    @property
    def Color(self) -> 'PdfRGBColor':
        """
        Gets or sets the color.
        """
        GetDllLibPdf().PdfBookmark_get_Color.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_get_Color.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfBookmark_get_Color,self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @Color.setter
    def Color(self, value: 'PdfRGBColor'):
        """
        Sets the color.
        """
        GetDllLibPdf().PdfBookmark_set_Color.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfBookmark_set_Color,self.Ptr, value.Ptr)

    @property
    def DisplayStyle(self) -> 'PdfTextStyle':
        """
        Gets or sets the text style.
        """
        GetDllLibPdf().PdfBookmark_get_DisplayStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_get_DisplayStyle.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfBookmark_get_DisplayStyle,self.Ptr)
        objwrapped = PdfTextStyle(ret)
        return objwrapped

    @DisplayStyle.setter
    def DisplayStyle(self, value: 'PdfTextStyle'):
        """
        Sets the text style.
        """
        GetDllLibPdf().PdfBookmark_set_DisplayStyle.argtypes = [c_void_p, c_int]
        CallCFunction(GetDllLibPdf().PdfBookmark_set_DisplayStyle,self.Ptr, value.value)

    @property
    def ExpandBookmark(self) -> bool:
        """
        Gets or sets whether to expand or collapse the node.
        """
        GetDllLibPdf().PdfBookmark_get_ExpandBookmark.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_get_ExpandBookmark.restype = c_bool
        ret = CallCFunction(GetDllLibPdf().PdfBookmark_get_ExpandBookmark,self.Ptr)
        return ret

    @ExpandBookmark.setter
    def ExpandBookmark(self, value: bool):
        """
        Sets whether to expand or collapse the node.
        """
        GetDllLibPdf().PdfBookmark_set_ExpandBookmark.argtypes = [c_void_p, c_bool]
        CallCFunction(GetDllLibPdf().PdfBookmark_set_ExpandBookmark,self.Ptr, value)

    @property
    def Action(self) -> 'PdfAction':
        """
        Gets or sets the Action for the Outline.
        """
        GetDllLibPdf().PdfBookmark_get_Action.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_get_Action.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfBookmark_get_Action,self.Ptr)
        ret = None if intPtr == None else PdfAction(intPtr)
        return ret

    @Action.setter
    def Action(self, value: 'PdfAction'):
        """
        Sets the Action for the Outline.
        """
        GetDllLibPdf().PdfBookmark_set_Action.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfBookmark_set_Action,self.Ptr, value.Ptr)

    def ConvertToBookmarkCollection(self) -> 'PdfBookmarkCollection':
        """
        Converts the bookmark to a bookmark collection.
        """
        from spire.pdf.PdfBookmarkCollection import PdfBookmarkCollection
        GetDllLibPdf().PdfBookmark_ConvertToBookmarkCollection.argtypes = [c_void_p]
        GetDllLibPdf().PdfBookmark_ConvertToBookmarkCollection.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfBookmark_ConvertToBookmarkCollection,self.Ptr)
        ret = None if intPtr == None else PdfBookmarkCollection(intPtr)
        return ret
